import {
	Notice,
	type App,
	type Editor,
	type MarkdownFileInfo,
	type MarkdownView,
} from "obsidian";
import { Command, EditorCheckCommand } from "./Command";
import type { BookTrackerPluginSettings } from "@ui/settings";
import type { ReadingLog } from "@utils/ReadingLog";
import { TO_BE_READ_STATE } from "@src/const";

export class ResetReadingStatusCommand extends EditorCheckCommand {
	constructor(
		private readonly app: App,
		private readonly readingLog: ReadingLog,
		private readonly settings: BookTrackerPluginSettings
	) {
		super("reset-reading-status", "Reset Reading Status");
	}

	protected check(
		_editor: Editor,
		ctx: MarkdownView | MarkdownFileInfo
	): boolean {
		return !(
			ctx.file === null ||
			this.settings.statusProperty === "" ||
			this.settings.startDateProperty === "" ||
			this.settings.endDateProperty === ""
		);
	}

	protected run(
		_editor: Editor,
		ctx: MarkdownView | MarkdownFileInfo
	): void | Promise<void> {
		const file = ctx.file!;

		this.app.fileManager.processFrontMatter(file, (frontMatter) => {
			frontMatter[this.settings.statusProperty] = TO_BE_READ_STATE;
			frontMatter[this.settings.startDateProperty] = "";
			frontMatter[this.settings.endDateProperty] = "";
		});

		this.readingLog.removeEntries(file.basename);

		new Notice("Reading status reset for " + file.basename);
	}
}
