import { App } from "obsidian";
import * as Handlebars from "handlebars";

Handlebars.registerHelper("formatDate", (date: Date, format: string) => {
	// @ts-ignore
	return moment(date).format(format);
});

Handlebars.registerHelper("now", (format: string) => {
	// @ts-ignore
	return moment().format(format);
});

Handlebars.registerHelper("normalizeDesc", (desc: string) => {
	if (!desc) return "";
	return desc.replace(/(\r\n|\n|\r)/gm, " ").trim();
});

export class Templater {
	public constructor(private readonly app: App) {}

	private async getTemplateContent(filePath: string): Promise<string | null> {
		const file = this.app.vault.getFileByPath(filePath);
		if (file === null) return null;

		try {
			return await this.app.vault.read(file);
		} catch (error) {
			console.error("Failed to read template file:", error);
			return null;
		}
	}

	public renderTemplate(
		templateContent: string,
		data: Record<string, unknown>
	): string {
		const template = Handlebars.compile(templateContent);
		return template(data);
	}

	public async renderTemplateFile(
		filePath: string,
		data: Record<string, any>
	): Promise<string | null> {
		const templateContent = await this.getTemplateContent(filePath);
		if (!templateContent) return null;

		return this.renderTemplate(templateContent, data);
	}
}
